hstrat.hstrat.stratum\_retention\_predicates.StratumRetentionPredicatePerfectResolution
=======================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_predicates

.. autoclass:: StratumRetentionPredicatePerfectResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionPredicatePerfectResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionPredicatePerfectResolution.CalcNumStrataRetainedExact
      ~StratumRetentionPredicatePerfectResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionPredicatePerfectResolution.CalcRankAtColumnIndex
      ~StratumRetentionPredicatePerfectResolution.__init__
   
   

   
   
   